#!/usr/bin/env python3

from squad_client.manage import main
import sys

sys.exit(main())
